import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_authentication/senior_authentication.dart';

import 'authentication/bloc/authentication_bloc.dart';
import 'home/home_screen.dart';
import 'splash/splash_screen.dart';

class ExampleApp extends StatelessWidget {
  const ExampleApp({
    Key? key,
    required this.authenticationRepository,
  }) : super(key: key);

  final AuthenticationRepository authenticationRepository;

  @override
  Widget build(BuildContext context) {
    return RepositoryProvider.value(
      value: authenticationRepository,
      child: BlocProvider(
        create: (_) => AuthenticationBloc(
          authenticationRepository: authenticationRepository,
        ),
        child: ExampleAppView(),
      ),
    );
  }
}

class ExampleAppView extends StatefulWidget {
  ExampleAppView({Key? key}) : super(key: key);

  @override
  _ExampleAppViewState createState() => _ExampleAppViewState();
}

class _ExampleAppViewState extends State<ExampleAppView> {
  final _navigatorKey = GlobalKey<NavigatorState>();

  NavigatorState get _navigator => _navigatorKey.currentState!;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      navigatorKey: _navigatorKey,
      title: 'Example',
      theme: ThemeData(
        primaryColor: Color(0xFF0E866A),
        visualDensity: VisualDensity.adaptivePlatformDensity,
        scaffoldBackgroundColor: Colors.white,
      ),
      debugShowCheckedModeBanner: false,
      initialRoute: 'splash',
      routes: {
        'splash': (ctx) => SplashScreen(),
        'home': (ctx) => HomeScreen(),
      },
      builder: (context, child) {
        return BlocListener<AuthenticationBloc, AuthenticationState>(
          child: child,
          listener: (context, state) async {
            switch (state.status) {
              case AuthenticationStatus.authenticated:
                _navigator.pushNamedAndRemoveUntil<void>(
                  "home",
                  (route) => false,
                );
                break;
              case AuthenticationStatus.unauthenticated:
                _navigator.pushAndRemoveUntil<void>(
                  MaterialPageRoute(builder: (ctx) => UsernameScreen()),
                  (route) => false,
                );
                break;
              case AuthenticationStatus.unknown:
              default:
                break;
            }
          },
        );
      },
    );
  }
}
